.. title:: De gif toedieningen zijn de foltering !!

.. _pvp:


.. raw:: html

    <br>
    <center>

pvp
===

.. raw:: html

    </center>
    <br>


Het is voor mij niet mogelijk gebleken om :ref:`aangifte <aangifte>` te doen van mishandeling als de psychiater zijn patient met gif mishandelt:

1) De IGZ treft geen structurele :ref:`onzorgvuldigheid <igz>` in de afhandeling van klachten bij GGZ-NHN aan.
2) De :ref:`Hoge Raad <hogeraad>` concludeert dat het geen verantwoordelijkheid heeft en verwijst naar het Openbaar Ministerie, dat niet reageert.
3) Daarna heb ik het Europeese Hof voor de Rechten van de Mens aangeschreven om een :ref:`klacht <greffe>` tegen Nederland in te dienen. 
4) De :ref:`Koningin <beuker>` kan hier geen verder tussenkomst verlenen.
5) :ref:`Uitspraak <uitspraak>` is niet-ontvankelijk.
6) Pas na een gang langs het EVRM reageert Het :ref:`Openbaar Ministerie <om>` wel en verwijst naar de IGZ, die de klacht melding al heeft afgesloten. 

Het is een plicht van het OM om mishandeling gepleegd door toediening van voor het leven of de gezondheid schadelijke stoffen te vervolgen.
Nalaten te vervolgen maakt dat miljoenen patienten door hun artsen vergiftigt worden, zonder zicht op het einde aan deze mishandelingen.

